# edge-ai

A python package to transform data into hardware-agnostic, embedded AI models using the Edge Impulse API.

## Local Development Environment

### Dependencies

- python >= 3.9
- pip
- git

### Setup

Run the top level `setup.sh` script which will check for, and install, the necessary dependencies:
```shell
bash scripts/setup.sh
```

Once setup is completed, you should be able to run the module's tests with:
```shell
bash scripts/test.sh
```

## How this repo was created

Primarily followed the [freecodecamp tutorial](https://www.freecodecamp.org/news/how-to-create-and-upload-your-first-python-package-to-pypi/)